@@ -57,8 +57,12 @@ class Download:
         insert_total_tracks(album['tracks'])
 
         # Construct album path
-        self.album_path = os.path.join(
-            self.settings['path'], sanitize(album['artist_disp_nm']), f"{sanitize(album['artist_disp_nm'])} - {sanitize(album['title'])}")
+        if self.settings['artist_folders'].upper() == 'Y':
+            self.album_path = os.path.join(
+                self.settings['path'], sanitize(album['artist_disp_nm']), f"{sanitize(album['artist_disp_nm'])} - {sanitize(album['title'])}")
+        else:
+            self.album_path = os.path.join(
+                self.settings['path'], f"{sanitize(album['artist_disp_nm'])} - {sanitize(album['title'])}")
         if not os.path.exists(self.album_path):
             logger.debug(f"Creating {self.album_path}")
             os.makedirs(self.album_path)
@@ -98,7 +102,7 @@ class Download:
         else:
             # Directory management
             file_path = os.path.join(
-                self.album_path, f"{track['track_no']}. {track['track_title']}.{determine_quality(track['svc_flac_yn'])}")
+                self.album_path, f"{track['track_no']}. {sanitize(track['track_title'])}.{determine_quality(track['svc_flac_yn'])}")
             with open(file_path, 'wb') as f:
                 for chunk in r.iter_content(32 * 1024):
                     if chunk:
@@ -213,13 +217,15 @@ class Download:
                 f'[{datetime.fromtimestamp(round(float(a), 2)).strftime("%M:%S.%f")[0:-4]}]{b}' for a, b in
                 line_split))
         # If user prefers untimed or the only available is untimed then use untimed
-        if 'lyrics_tp' == 'N' or self.settings['lyrics'] == 'N':
+        elif 'lyrics_tp' == 'N' or self.settings['lyrics'] == 'N':
             r = requests.get(
                 'https://music.bugs.co.kr/player/lyrics/N/{}'.format(str(track_id)))
             lyrics = r.json()['lyrics']
             # If unavailable leave as empty string
             if lyrics_tp is None:
                 lyrics = ""
+        else:
+            lyrics = ""
         return lyrics
 
     @logger.catch
