@@ -4,7 +4,7 @@ from loguru import logger
 from urllib.parse import unquote
 from mutagen.flac import FLAC
 from rsack.clients import genie
-from rsack.utils import Settings, get_ext, sanitize
+from rsack.utils import Settings, format_genie_lyrics, get_ext, sanitize, format_genie_lyrics
 from concurrent.futures import ThreadPoolExecutor
 
 class Download:
@@ -32,6 +32,7 @@ class Download:
         for album in self.meta['DataSet']['DATA']:
             self._album(album['ALBUM_ID'])
 
+    @logger.catch
     def _album(self, id):
         """Iterate tracks in the album list
 
@@ -79,6 +80,7 @@ class Download:
             executor.map(self._track, tracks, track_numbers,
                          disc_numbers, track_artist)
 
+    @logger.catch
     def _track(self, id, track_number, disc_number, track_artist):
         meta = self.client.get_stream_meta(id, '24bit')
         logger.info(f"Track: {unquote(meta['SONG_NAME'])}")
@@ -87,14 +89,22 @@ class Download:
             self.album_path, f"{track_number}. {sanitize(unquote(meta['SONG_NAME']))}.{ext}")
         r = self.client.session.get(unquote(meta['STREAMING_MP3_URL']))
         r.raise_for_status()
-        with open(file_path, 'wb') as f:
-            for chunk in r.iter_content(32 * 1024):
-                if chunk:
-                    f.write(chunk)
-        self._fix_tags(file_path, ext, track_number, disc_number,
-                       track_artist, unquote(meta['SONG_NAME']))
+        # Retrieve lyrics
+        lyrics = self.client.get_timed_lyrics(id)
+        if self.settings['timed_lyrics'] == 'Y' and lyrics != None:
+            lyrics = format_genie_lyrics(lyrics)
+        if os.path.exists(file_path):
+            logger.debug(f"{file_path} already exists.")
+        else:
+            with open(file_path, 'wb') as f:
+                for chunk in r.iter_content(32 * 1024):
+                    if chunk:
+                        f.write(chunk)
+            self._fix_tags(file_path, lyrics, ext, track_number, disc_number,
+                        track_artist, unquote(meta['SONG_NAME']))
 
-    def _fix_tags(self, path, ext, track_number, disc_number, track_artist, track_title):
+    @logger.catch
+    def _fix_tags(self, path, lyrics, ext, track_number, disc_number, track_artist, track_title):
         if ext == "mp3":
             try:
                 audio = id3.ID3(path)
@@ -111,6 +121,8 @@ class Download:
             audio['TPUB'] = id3.TPUB(text=self.f_meta['planning'])
             audio['TPE1'] = id3.TPE1(text=unquote(track_artist))
             audio['TPE2'] = id3.TPE2(text=self.f_meta['album_artist'])
+            if lyrics != None:
+                audio['USLT'] = id3.USLT(text=lyrics)
             audio.save(path, "v2_version=3")
         else:
             audio = FLAC(path)
@@ -120,6 +132,8 @@ class Download:
             audio['LABEL'] = self.f_meta['planning']
             audio['ARTIST'] = unquote(track_artist)
             audio['ALBUMARTIST'] = self.f_meta['album_artist']
+            if lyrics != None:
+                audio['LYRICS'] = lyrics
             audio.save()
 
     def _download_cover(self, url):
